from typing import Annotated

from fastapi import APIRouter, Depends

from fastfood_two.application.contracts.responses import MenuResponse
from fastfood_two.application.usecases.menu.get_all_menus import GetAllMenus
from fastfood_two.presentation.fastapi_backend.depends.stub import Stub

router = APIRouter(prefix="/menu", tags=["Menu"])


@router.get("/", response_model=list[MenuResponse])
async def get_all_menus(
    usecase: Annotated[GetAllMenus, Depends(Stub(GetAllMenus))],
) -> list[MenuResponse]:
    """Get all menus.

    Endpoint returns list of all available food menus
    """
    menus = await usecase()
    return menus
